ActionPollError

Enum ActionPollError 

pub enum ActionPollError {
Show 14 variants ResponsePending, UnexpectedObservation, Terminal, MonotonicRollback, TimeOverflow, ObservationLimitExceeded, InvalidProgress, ProgressRegressed, ProgressResetForbidden, ProgressResetLimitExceeded, ZeroDelay, DelayLimitExceeded, CumulativeDelayExceeded, ElapsedBudgetExceeded,
}
Structural action workflow failure.

Variants



ResponsePending

Another request cannot start before its response is observed.



UnexpectedObservation

A response was supplied without one admitted request.



Terminal

The workflow already reached a terminal state.



MonotonicRollback

Caller monotonic time moved backwards.



TimeOverflow

Monotonic timestamp arithmetic overflowed.



ObservationLimitExceeded

The unconditional observation limit was reached while still running.



InvalidProgress

Provider progress exceeded 100.



ProgressRegressed

Provider progress regressed without an explicit reset.



ProgressResetForbidden

Provider progress reset was not admitted.



ProgressResetLimitExceeded

Provider progress exhausted its reset budget.



ZeroDelay

Backoff requested a zero delay.



DelayLimitExceeded

Backoff requested more than the per-delay bound.



CumulativeDelayExceeded

Backoff exhausted the cumulative delay budget.



ElapsedBudgetExceeded

Backoff would reach or exceed the elapsed budget.