pub enum ActionPollLimitsError {
Zero,
DelayExceedsCumulative,
DelayExceedsElapsed,
}Expand description
Invalid hard action-poll limits.
Variants
Zero
Every hard limit must be nonzero.
DelayExceedsCumulative
One delay may not exceed the cumulative delay budget.
DelayExceedsElapsed
One delay may not meet or exceed the elapsed budget.