pub enum ActionPollStep<E> {
Delay(Duration),
Complete,
Failed(E),
Cancelled,
TimedOut,
}Expand description
Step returned after one accepted observation.
Variants
Delay(Duration)
The caller must wait before requesting the action again.
Complete
The action completed successfully.
Failed(E)
The provider reported a terminal action failure.
Cancelled
Caller policy cancelled polling.
TimedOut
Caller policy stopped polling at its deadline or attempt budget.