pub struct ActionPollLimits { /* private fields */ }Expand description
Unconditional request, delay, and elapsed limits.
Implementations
Sourceimpl ActionPollLimits
impl ActionPollLimits
Sourcepub const fn new(
max_observations: u32,
max_delay: MonotonicDuration,
max_cumulative_delay: MonotonicDuration,
max_elapsed: MonotonicDuration,
) -> Result<Self, ActionPollLimitsError>
pub const fn new( max_observations: u32, max_delay: MonotonicDuration, max_cumulative_delay: MonotonicDuration, max_elapsed: MonotonicDuration, ) -> Result<Self, ActionPollLimitsError>
Creates complete hard limits selected before the first request.
Sourcepub const fn max_observations(self) -> u32
pub const fn max_observations(self) -> u32
Returns the maximum accepted provider observations.
Sourcepub const fn max_delay(self) -> MonotonicDuration
pub const fn max_delay(self) -> MonotonicDuration
Returns the maximum delay admitted from any backoff policy.
Sourcepub const fn max_cumulative_delay(self) -> MonotonicDuration
pub const fn max_cumulative_delay(self) -> MonotonicDuration
Returns the cumulative requested-delay budget.
Sourcepub const fn max_elapsed(self) -> MonotonicDuration
pub const fn max_elapsed(self) -> MonotonicDuration
Returns the monotonic elapsed-time budget.