pub enum CredentialLifetimeError {
ZeroExpiresIn,
ZeroRefreshWindow,
RefreshWindowTooLarge,
TimestampOverflow,
}Expand description
Invalid OAuth-style credential lifetime.
Variants
ZeroExpiresIn
expires_in must be nonzero.
ZeroRefreshWindow
Refresh lead time must be nonzero so a refresh window exists.
RefreshWindowTooLarge
Refresh lead time must leave a nonempty fresh interval.
TimestampOverflow
The caller timestamp and expires_in overflow the representation.