CanonicalSigningInput

Struct CanonicalSigningInput 

pub struct CanonicalSigningInput<'storage, 'request> { /* private fields */ }
Cleanup-owning canonical input that retains the exact hashed request.

Implementations

Source

impl<'storage, 'request> CanonicalSigningInput<'storage, 'request>

pub fn new_hashed<H: RequestBodyHasher + ?Sized>( request: TransportRequest<'request>, context: SigningContext<'request>, selected_headers: SigningHeaders<'_>, freshness: SigningFreshness<'_>, hasher: &H, digest_storage: &mut [u8], output: &'storage mut [u8], ) -> Result<Self, SigningBuildError<H::Error>>

Hashes the exact request body and builds a security-domain-bound input.

pub fn as_bytes(&self) -> &[u8]

Returns the exact bytes to hash or sign.

pub const fn request(&self) -> TransportRequest<'request>

Returns the exact request retained by the canonical snapshot.

pub const fn context(&self) -> SigningContext<'request>

Returns the exact security domain retained by the canonical snapshot.

pub fn sign_into<'signature, S: RequestSigner>( self, signer: &S, output: &'signature mut [u8], ) -> Result<SignedRequest<'signature, 'request>, SigningOutputError<S::Error>>

Signs and returns the exact request with cleanup-owning bounded output.