BoundCredentialTransport

Trait BoundCredentialTransport 

pub trait BoundCredentialTransport {
    // Required method
    fn credential_binding(&self) -> CredentialBinding;
}
Authenticated transport exposing its current opaque credential lineage.

This contract is required only by provider operations whose authorization depends on a prior authenticated observation. Implementations must return the binding of the credential that send_authenticated will use.

Required Methods

fn credential_binding(&self) -> CredentialBinding

Returns the current transport credential lifecycle.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors