pub enum CheckedDecodeError<E> {
ResponseWriter(ResponseWriterError),
ResponsePolicy(ResponsePolicyError),
ExpectedErrorStatus,
Decoder(E),
}Expand description
Failure while entering a checked success or provider-error decoder.
Variants
ResponseWriter(ResponseWriterError)
The response writer did not contain one committed response.
ResponsePolicy(ResponsePolicyError)
Success status, body, media, or metadata policy rejected the response.
ExpectedErrorStatus
Provider-error decoding was requested for a non-error status.
Decoder(E)
The provider-owned decoder rejected the bounded response.