pub struct OwnedClientWorkspace { /* private fields */ }Expand description
Fallibly allocated complete workspace cleared in full on drop.
Implementations
Sourceimpl OwnedClientWorkspace
impl OwnedClientWorkspace
Sourcepub fn try_for_profile(
profile: ClientCapacityProfile,
) -> Result<Self, ClientCapacityError>
pub fn try_for_profile( profile: ClientCapacityProfile, ) -> Result<Self, ClientCapacityError>
Allocates exactly one named profile without panicking on allocation failure.
Sourcepub fn workspace(&mut self) -> ClientWorkspace<'_>
pub fn workspace(&mut self) -> ClientWorkspace<'_>
Borrows all four allocations as one cleanup-owning workspace.