pub struct DiagnosticContext { /* private fields */ }Expand description
Validated provider and operation context for one lifecycle event.
Implementations
Sourceimpl DiagnosticContext
impl DiagnosticContext
Sourcepub const fn provider(self) -> ProviderId
pub const fn provider(self) -> ProviderId
Returns the validated provider identifier.
Sourcepub const fn service(self) -> ServiceId
pub const fn service(self) -> ServiceId
Returns the validated provider-owned service identifier.
Sourcepub const fn operation(self) -> Option<OperationId>
pub const fn operation(self) -> Option<OperationId>
Returns the provider operation identifier when one was bound.
Sourcepub const fn impact(self) -> OperationImpact
pub const fn impact(self) -> OperationImpact
Returns the validated operation impact.
Sourcepub const fn retry(self) -> DiagnosticRetryCategory
pub const fn retry(self) -> DiagnosticRetryCategory
Returns the operation retry category.