pub enum ContentTypePolicy {
Required(&'static [MediaType<'static>]),
Optional(&'static [MediaType<'static>]),
Forbidden,
}Expand description
Response content-type requirement and accepted media types.
Variants
Required(&'static [MediaType<'static>])
A content type is required and must match one accepted media type.
Optional(&'static [MediaType<'static>])
A content type may be absent, but when present it must match.
Forbidden
Any response content type is rejected.