pub enum OperationImpact {
ReadOnly,
Mutation,
Destructive,
}Expand description
Provider operation impact.
Variants
ReadOnly
The operation cannot change provider state.
Mutation
The operation changes provider state without being inherently destructive.
Destructive
The operation deletes, disables, resets, detaches, or otherwise destroys state.