pub enum RequestSemantics {
Safe,
Idempotent,
NonIdempotent,
}Expand description
HTTP request semantics independent of provider impact.
Variants
Safe
Repeating the request is both read-only and idempotent.
Idempotent
Repeating the request has the same intended effect, but it changes state.
NonIdempotent
Repeating the request can create an additional or different effect.