PrepareOperation

Trait PrepareOperation 

pub trait PrepareOperation {
    type Error;

    // Required method
    fn prepare<'storage>(
        &self,
        storage: PreparationStorage<'storage>,
    ) -> Result<PreparedRequest<'storage>, Self::Error>;
}
Typed provider operation that can prepare one complete request.

use cloud_sdk::operation::PrepareOperation;

fn prepare_without_storage<O: PrepareOperation>(operation: &O) {
    let _ = operation.prepare();
}

Required Associated Types

type Error

Preparation-specific failure.

Required Methods

fn prepare<'storage>( &self, storage: PreparationStorage<'storage>, ) -> Result<PreparedRequest<'storage>, Self::Error>

Writes into caller storage and returns an executable prepared request.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors