pub struct HeaderCursorSession<'request, 'policy> { /* private fields */ }Expand description
Exact prepared-request context retained for one header-cursor traversal.
Implementations
Sourceimpl HeaderCursorSession<'_, '_>
impl HeaderCursorSession<'_, '_>
Sourcepub async fn execute_async<'response, 'cursor, 'endpoint, T>(
&self,
transport: &'endpoint T,
response_storage: &'response mut [u8],
response_header_storage: &'response mut [u8],
decimal_scratch: &mut [u8],
transfer_scratch: &mut [u8],
cursor_destination: &'cursor mut [u8],
limits: PaginationLimits,
) -> Result<HeaderCursorPage<'response, 'cursor, 'endpoint, '_, '_, '_>, HeaderCursorExecutionError<T::Error>>where
T: AsyncAuthenticatedTransport + BoundTransport,
pub async fn execute_async<'response, 'cursor, 'endpoint, T>(
&self,
transport: &'endpoint T,
response_storage: &'response mut [u8],
response_header_storage: &'response mut [u8],
decimal_scratch: &mut [u8],
transfer_scratch: &mut [u8],
cursor_destination: &'cursor mut [u8],
limits: PaginationLimits,
) -> Result<HeaderCursorPage<'response, 'cursor, 'endpoint, '_, '_, '_>, HeaderCursorExecutionError<T::Error>>where
T: AsyncAuthenticatedTransport + BoundTransport,
Executes the initial executor-neutral async request and decodes its response.
Sourceimpl HeaderCursorSession<'_, '_>
impl HeaderCursorSession<'_, '_>
Sourcepub async fn execute_local_async<'response, 'cursor, 'endpoint, T>(
&self,
transport: &'endpoint T,
response_storage: &'response mut [u8],
response_header_storage: &'response mut [u8],
decimal_scratch: &mut [u8],
transfer_scratch: &mut [u8],
cursor_destination: &'cursor mut [u8],
limits: PaginationLimits,
) -> Result<HeaderCursorPage<'response, 'cursor, 'endpoint, '_, '_, '_>, HeaderCursorExecutionError<T::Error>>where
T: LocalAsyncAuthenticatedTransport + BoundTransport,
pub async fn execute_local_async<'response, 'cursor, 'endpoint, T>(
&self,
transport: &'endpoint T,
response_storage: &'response mut [u8],
response_header_storage: &'response mut [u8],
decimal_scratch: &mut [u8],
transfer_scratch: &mut [u8],
cursor_destination: &'cursor mut [u8],
limits: PaginationLimits,
) -> Result<HeaderCursorPage<'response, 'cursor, 'endpoint, '_, '_, '_>, HeaderCursorExecutionError<T::Error>>where
T: LocalAsyncAuthenticatedTransport + BoundTransport,
Executes the initial local async request and decodes its own response.
Sourceimpl HeaderCursorSession<'_, '_>
impl HeaderCursorSession<'_, '_>
Sourcepub const fn operation_id(&self) -> OperationId
pub const fn operation_id(&self) -> OperationId
Returns the operation retained by this exact request context.
Sourcepub fn execute_blocking<'response, 'cursor, 'endpoint, T>(
&self,
transport: &'endpoint T,
response_storage: &'response mut [u8],
response_header_storage: &'response mut [u8],
decimal_scratch: &mut [u8],
transfer_scratch: &mut [u8],
cursor_destination: &'cursor mut [u8],
limits: PaginationLimits,
) -> Result<HeaderCursorPage<'response, 'cursor, 'endpoint, '_, '_, '_>, HeaderCursorExecutionError<T::Error>>where
T: BlockingAuthenticatedTransport + BoundTransport,
pub fn execute_blocking<'response, 'cursor, 'endpoint, T>(
&self,
transport: &'endpoint T,
response_storage: &'response mut [u8],
response_header_storage: &'response mut [u8],
decimal_scratch: &mut [u8],
transfer_scratch: &mut [u8],
cursor_destination: &'cursor mut [u8],
limits: PaginationLimits,
) -> Result<HeaderCursorPage<'response, 'cursor, 'endpoint, '_, '_, '_>, HeaderCursorExecutionError<T::Error>>where
T: BlockingAuthenticatedTransport + BoundTransport,
Executes the initial blocking request and decodes only its own response.