pub struct ProviderLinkBinding<'a> { /* private fields */ }Expand description
Immutable operation boundary used to validate provider pagination links.
Implementations
Sourceimpl<'a> ProviderLinkBinding<'a>
impl<'a> ProviderLinkBinding<'a>
Sourcepub const fn new(
endpoint: EndpointIdentity<'a>,
method: Method,
operation: OperationId,
path: RequestPath<'a>,
) -> Self
pub const fn new( endpoint: EndpointIdentity<'a>, method: Method, operation: OperationId, path: RequestPath<'a>, ) -> Self
Binds links to one endpoint, method, operation, and exact path pattern.