pub enum QuotaError {
BucketIdEmpty,
BucketIdTooLong,
InvalidBucketId,
LimitZero,
RemainingExceedsLimit,
TooManyBuckets,
DuplicateBucket,
TooManyExtensions,
DuplicateExtension,
}Expand description
Invalid quota bucket or bounded collection.
Variants
BucketIdEmpty
A bucket identity was empty.
BucketIdTooLong
A bucket identity exceeded its fixed bound.
InvalidBucketId
A bucket identity contained unsupported bytes.
LimitZero
A bucket limit was zero.
RemainingExceedsLimit
Remaining requests exceeded the bucket limit.
TooManyBuckets
More than the bounded number of buckets was supplied.
DuplicateBucket
A bucket identity appeared more than once.
TooManyExtensions
More than the bounded number of extensions was supplied.
DuplicateExtension
An extension name appeared more than once in a bucket.