pub struct RateLimit { /* private fields */ }Expand description
Validated rate-limit metadata returned by a transport.
Implementations
Sourceimpl RateLimit
impl RateLimit
Sourcepub const fn new(
limit: u64,
remaining: u64,
reset_epoch_seconds: u64,
) -> Result<Self, RateLimitError>
pub const fn new( limit: u64, remaining: u64, reset_epoch_seconds: u64, ) -> Result<Self, RateLimitError>
Creates coherent rate-limit metadata.
Sourcepub const fn remaining(self) -> u64
pub const fn remaining(self) -> u64
Returns the number of requests remaining in the current time frame.
Sourcepub const fn reset_epoch_seconds(self) -> u64
pub const fn reset_epoch_seconds(self) -> u64
Returns the provider reset time as Unix epoch seconds.