Module transport

Module transport 

Provider-neutral blocking and asynchronous transport contracts.

Structs

ContentType
Borrowed, validated HTTP content type.
RequestTarget
Validated origin-form HTTP request target.
StatusCode
Valid HTTP response status code.
TransportRequest
Provider-neutral request passed to a blocking transport.
TransportResponse
Response returned after a transport initializes part of a caller buffer.

Enums

ContentTypeError
Content-type validation error.
RequestTargetError
Request-target validation error.

Constants

MAX_CONTENT_TYPE_BYTES
Maximum content-type header value length admitted by the core contract.
MAX_REQUEST_TARGET_BYTES
Maximum origin-form request-target length admitted by the core contract.

Traits

AsyncTransport
Asynchronous transport over caller-owned request and response buffers.
BlockingTransport
Synchronous transport over caller-owned request and response buffers.