pub enum EndpointPolicyError {
EmptyOfficialSet,
TooManyOfficialEndpoints,
InvalidRegion,
DestinationMismatch,
}Expand description
Endpoint trust policy validation or matching error.
Variants
EmptyOfficialSet
A finite official endpoint set must not be empty.
TooManyOfficialEndpoints
A finite official endpoint set exceeds MAX_OFFICIAL_ENDPOINTS.
InvalidRegion
A region identifier is not bounded canonical lowercase ASCII.
DestinationMismatch
The candidate endpoint is not admitted by the policy.