pub enum RawResponsePolicyError {
InformationalLimitTooLarge,
BodyLimitTooLarge,
MissingMediaType,
DuplicateMediaType,
TooManyAdmittedHeaders,
DuplicateAdmittedHeader,
UnsafeAdmittedHeader,
ForbiddenMediaHasBodyLimit,
}Expand description
Invalid raw response-wire policy.
Variants
InformationalLimitTooLarge
An informational-response limit exceeded the global hard ceiling.
BodyLimitTooLarge
A body limit exceeded the buffered raw-response ceiling.
MissingMediaType
Required or optional media policy omitted accepted media types.
DuplicateMediaType
A media policy contains duplicate media-type essences.
TooManyAdmittedHeaders
Too many response-header names were admitted.
DuplicateAdmittedHeader
Admitted response-header names contain a duplicate.
UnsafeAdmittedHeader
Credential, cookie, framing, proxy, or upgrade response metadata was admitted.
ForbiddenMediaHasBodyLimit
A status class forbids media and body data but has a nonzero body limit.