ResponseMediaPolicy

Enum ResponseMediaPolicy 

pub enum ResponseMediaPolicy<'a> {
    Required(&'a [MediaType<'a>]),
    Optional(&'a [MediaType<'a>]),
    Forbidden,
}
Response media-type requirement for one status class.

Variants



Required(&'a [MediaType<'a>])

A content type is required and must match one admitted essence.



Optional(&'a [MediaType<'a>])

A content type may be absent, but a present value must match.



Forbidden

A content type and response body are forbidden.