pub enum StreamRead {
Chunk(usize),
Wait,
End,
}Expand description
One source observation.
Variants
Chunk(usize)
One chunk was initialized in the supplied scratch prefix.
Wait
The source was observed but produced no chunk in this turn.
End
The finite source reached end-of-stream.