pub enum StreamSinkMode {
Transactional,
Direct,
}Expand description
Visibility of accepted bytes before successful completion.
Variants
Transactional
Accepted bytes remain hidden and the sink can roll them back on abort.
Direct
Accepted bytes may be externally visible and cannot be rolled back.