pub enum StructuredQueryError {
TooLong,
InvalidByte,
EmptyPair,
EmptyKey,
MultipleEquals,
InvalidPercentTriplet,
LowercasePercentHex,
EncodedControl,
EncodedUnreserved,
PlusForbidden,
}Expand description
Structured query validation error.
Variants
TooLong
Queries exceed MAX_REQUEST_TARGET_BYTES.
InvalidByte
A raw byte is outside the admitted ASCII query grammar.
EmptyPair
Empty &-delimited pairs are forbidden.
EmptyKey
Query keys must not be empty.
MultipleEquals
A query pair contains more than one raw =.
InvalidPercentTriplet
A percent triplet is incomplete or malformed.
LowercasePercentHex
Percent hexadecimal digits must be uppercase.
EncodedControl
A percent triplet encodes a control byte or fragment delimiter.
EncodedUnreserved
An unreserved byte was needlessly percent encoded.
PlusForbidden
+ is forbidden outside an explicit form-query dialect.