pub struct TransportFailure<E> { /* private fields */ }Expand description
Payload-redacting transport failure with an explicit delivery phase.
Unknown send state must use Self::unknown, which conservatively maps to
DeliveryPhase::PossiblySent.
Implementations
Sourceimpl<E> TransportFailure<E>
impl<E> TransportFailure<E>
Sourcepub const fn not_sent(error: E) -> Self
pub const fn not_sent(error: E) -> Self
Records a failure proven to have happened before request delivery.
Sourcepub const fn possibly_sent(error: E) -> Self
pub const fn possibly_sent(error: E) -> Self
Records a failure after request delivery may have begun.
Sourcepub const fn response_started(error: E) -> Self
pub const fn response_started(error: E) -> Self
Records a failure after any response head was observed.
Sourcepub const fn unknown(error: E) -> Self
pub const fn unknown(error: E) -> Self
Conservatively records an error whose delivery state is unknown.
Sourcepub const fn phase(&self) -> DeliveryPhase
pub const fn phase(&self) -> DeliveryPhase
Returns the conservative delivery phase.
Sourcepub fn into_error(self) -> E
pub fn into_error(self) -> E
Consumes the failure and returns its adapter error.