Bounded provider-neutral asynchronous task and event response models.
Structs
- Async
Event - Bounded generic event model that makes no provider endpoint claim.
- Async
Event Batch - Borrowed event batch with an unconditional event-count bound.
- Async
Event Parts - Complete borrowed fields for one generic asynchronous event fixture.
- Async
Progress Step - One bounded progress step.
- Async
Resource Id - Bounded opaque asynchronous-resource identifier with redacted diagnostics.
- Async
Resource Link - Bounded non-executable related-resource link with redacted diagnostics.
- Async
Resource Text - Bounded sensitive asynchronous-resource text with redacted diagnostics.
- Async
Resource Timestamp - Strict UTC nanosecond RFC 3339 timestamp retained as borrowed sensitive text.
- Async
Task - Validated borrowed asynchronous task snapshot.
- Async
Task Error - One bounded provider task error with redacted diagnostics.
- Async
Task Parts - Complete borrowed fields used to validate one task snapshot.
Enums
- Async
Poll Disposition - Exhaustive polling disposition for one asynchronous task snapshot.
- Async
Resource Status - Provider-neutral lifecycle classification for asynchronous resources.
- Async
Resource Validation Error - Invalid asynchronous task or event data.
Constants
- MAX_
ASYNC_ ERRORS - Maximum errors retained in one task snapshot.
- MAX_
ASYNC_ EVENTS - Maximum events admitted in one borrowed event batch.
- MAX_
ASYNC_ ID_ BYTES - Maximum opaque asynchronous-resource identifier length.
- MAX_
ASYNC_ LINK_ BYTES - Maximum non-executable related-resource link length.
- MAX_
ASYNC_ PROGRESS_ STEPS - Maximum progress steps retained in one task snapshot.
- MAX_
ASYNC_ TEXT_ BYTES - Maximum task, progress, error, or event text length.