Provider-neutral blocking and asynchronous transport contracts.
Structs
- Content
Type - Borrowed, validated HTTP content type.
- Request
Target - Validated origin-form HTTP request target.
- Status
Code - Valid HTTP response status code.
- Transport
Request - Provider-neutral request passed to a blocking transport.
- Transport
Response - Response returned after a transport initializes part of a caller buffer.
Enums
- Content
Type Error - Content-type validation error.
- Request
Target Error - Request-target validation error.
Constants
- MAX_
CONTENT_ TYPE_ BYTES - Maximum content-type header value length admitted by the core contract.
- MAX_
REQUEST_ TARGET_ BYTES - Maximum origin-form request-target length admitted by the core contract.
Traits
- Async
Transport - Asynchronous transport over caller-owned request and response buffers.
- Blocking
Transport - Synchronous transport over caller-owned request and response buffers.