pub trait DeliveryClassified {
// Required method
fn delivery_phase(&self) -> DeliveryPhase;
// Provided method
fn observed_status(&self) -> Option<StatusCode> { ... }
}Expand description
Error whose furthest possible request-delivery phase is explicit.
Implementations should retain a final response status once observed so authentication and reconciliation policy can classify later failures.
Required Methods
Sourcefn delivery_phase(&self) -> DeliveryPhase
fn delivery_phase(&self) -> DeliveryPhase
Returns the conservative delivery phase for permit transitions.
Provided Methods
Sourcefn observed_status(&self) -> Option<StatusCode>
fn observed_status(&self) -> Option<StatusCode>
Returns a valid final status observed before the failure, when known.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".